Installation — CMIS Library v0.4.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- CMIS Library v0.4.1 documentation »

# Installation

## Requirements

These requirements must be met:
  - Python 2.6.x
  - CMIS provider compliant with CMIS 1.0

## Steps

> 1. If you don’t have Python installed already, do so.
> 2. If you don’t have setuptools installed already, do so.
> 3. Once setuptools is installed, type easy_install cmislib
> 4. That’s it!

Once you do that, you should be able to fire up Python on the command-line and import cmislib successfully.

    >>> from cmislib import CmisClient, Repository, Folder

To validate everything is working, run some Tests or walk through some Examples.

### Navigation

- index
- modules |
- next |
- previous |
- CMIS Library v0.4.1 documentation »